==> yawp-1.21.4-fabric-0.5.2-beta1-sources.jar: de/z0rdak/yawp/mixin/flag/mobgrief/SilverfishWakeUpFriendsGoalMixin.java <==
package de.z0rdak.yawp.mixin.flag.mobgrief;

import de.z0rdak.yawp.api.events.region.FlagCheckEvent;
import de.z0rdak.yawp.core.flag.FlagState;
import de.z0rdak.yawp.platform.Services;
import net.minecraft.class_1614;
import net.minecraft.class_1928;
import net.minecraft.class_1937;
import net.minecraft.class_2248;
import net.minecraft.class_2338;
import net.minecraft.class_2384;
import net.minecraft.class_2680;
import net.minecraft.class_3218;
import net.minecraft.class_5819;
import org.spongepowered.asm.mixin.Final;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Shadow;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;
import org.spongepowered.asm.mixin.injection.callback.LocalCapture;

import static de.z0rdak.yawp.core.flag.RegionFlag.MOB_GRIEFING;
import static de.z0rdak.yawp.handler.HandlerUtil.isServerSide;
import static de.z0rdak.yawp.handler.HandlerUtil.processCheck;

@Mixin(targets = "net.minecraft.world.entity.monster.Silverfish$SilverfishWakeUpFriendsGoal")
public abstract class SilverfishWakeUpFriendsGoalMixin {

    @Final
    @Shadow
    private class_1614 silverfish;

    // TODO: FIX implementation by stripping most of vanilla code    
    @Inject(method = "tick()V", locals = LocalCapture.CAPTURE_FAILSOFT, at = @At(value = "INVOKE", target = "Lnet/minecraft/world/level/Level;destroyBlock(Lnet/minecraft/core/BlockPos;ZLnet/minecraft/world/entity/Entity;)Z"))
    public void onSilverFishDestroyBlock(CallbackInfo ci, class_1937 level, class_5819 randomSource, class_2338 blockPos, int i) {
        if (isServerSide(silverfish)) {
            block0:
            while (i <= 5 && i >= -5) {
                int j = 0;
                while (j <= 10 && j >= -10) {
                    int k = 0;
                    while (k <= 10 && k >= -10) {
                        class_2338 blockPos2 = blockPos.method_10069(j, i, k);
                        class_2680 blockState = level.method_8320(blockPos2);
                        class_2248 block = blockState.method_26204();
                        if (block instanceof class_2384) {
                            FlagCheckEvent checkEvent = new FlagCheckEvent(blockPos2, MOB_GRIEFING, level.method_27983());
                            boolean isCanceled = Services.EVENT.post(checkEvent);
                            FlagState flagState = processCheck(checkEvent);
                            boolean isDenied = flagState == FlagState.DENIED;
                            if (isCanceled) {
                                isDenied = false;
                            }
                            if (!((class_3218)level).method_64395().method_8355(class_1928.field_19388) || isDenied) {
                                level.method_8651(blockPos2, true, this.silverfish);
                            } else {
                                level.method_8652(blockPos2, ((class_2384) block).method_10270(level.method_8320(blockPos2)), 3);
                            }
                            if (randomSource.method_43056()) break block0;
                        }
                        k = (k <= 0 ? 1 : 0) - k;
                    }
                    j = (j <= 0 ? 1 : 0) - j;
                }
                i = (i <= 0 ? 1 : 0) - i;
            }
        }
    }
}

==> yawp-1.21.5-fabric-0.6.2-beta1-sources.jar: de/z0rdak/yawp/mixin/flag/mobgrief/SilverfishWakeUpFriendsGoalMixin.java <==
package de.z0rdak.yawp.mixin.flag.mobgrief;

import de.z0rdak.yawp.api.events.region.FlagCheckEvent;
import de.z0rdak.yawp.core.flag.FlagState;
import de.z0rdak.yawp.platform.Services;
import net.minecraft.class_1614;
import net.minecraft.class_1928;
import net.minecraft.class_1937;
import net.minecraft.class_2248;
import net.minecraft.class_2338;
import net.minecraft.class_2384;
import net.minecraft.class_2680;
import net.minecraft.class_3218;
import net.minecraft.class_5819;
import org.spongepowered.asm.mixin.Final;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.Shadow;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfo;
import org.spongepowered.asm.mixin.injection.callback.LocalCapture;

import static de.z0rdak.yawp.core.flag.RegionFlag.MOB_GRIEFING;
import static de.z0rdak.yawp.handler.HandlerUtil.isServerSide;
import static de.z0rdak.yawp.api.FlagEvaluator.processCheck;

@Mixin(targets = "net.minecraft.world.entity.monster.Silverfish$SilverfishWakeUpFriendsGoal")
public abstract class SilverfishWakeUpFriendsGoalMixin {

    @Final
    @Shadow
    private class_1614 silverfish;

    // TODO: FIX implementation by stripping most of vanilla code    
    @Inject(method = "tick()V", locals = LocalCapture.CAPTURE_FAILSOFT, at = @At(value = "INVOKE", target = "Lnet/minecraft/world/level/Level;destroyBlock(Lnet/minecraft/core/BlockPos;ZLnet/minecraft/world/entity/Entity;)Z"))
    public void onSilverFishDestroyBlock(CallbackInfo ci, class_1937 level, class_5819 randomSource, class_2338 blockPos, int i) {
        if (isServerSide(silverfish)) {
            block0:
            while (i <= 5 && i >= -5) {
                int j = 0;
                while (j <= 10 && j >= -10) {
                    int k = 0;
                    while (k <= 10 && k >= -10) {
                        class_2338 blockPos2 = blockPos.method_10069(j, i, k);
                        class_2680 blockState = level.method_8320(blockPos2);
                        class_2248 block = blockState.method_26204();
                        if (block instanceof class_2384) {
                            FlagCheckEvent checkEvent = new FlagCheckEvent(blockPos2, MOB_GRIEFING, level.method_27983());
                            boolean isCanceled = Services.EVENT.post(checkEvent);
                            FlagState flagState = processCheck(checkEvent);
                            boolean isDenied = flagState == FlagState.DENIED;
                            if (isCanceled) {
                                isDenied = false;
                            }
                            if (!((class_3218)level).method_64395().method_8355(class_1928.field_19388) || isDenied) {
                                level.method_8651(blockPos2, true, this.silverfish);
                            } else {
                                level.method_8652(blockPos2, ((class_2384) block).method_10270(level.method_8320(blockPos2)), 3);
                            }
                            if (randomSource.method_43056()) break block0;
                        }
                        k = (k <= 0 ? 1 : 0) - k;
                    }
                    j = (j <= 0 ? 1 : 0) - j;
                }
                i = (i <= 0 ? 1 : 0) - i;
            }
        }
    }
}
